@@ -1,11 +1,3 @@
-//
-//  parameter.h
-//  Onelab
-//
-//  Created by Maxime Graulich on 07/08/13.
-//  Copyright (c) 2013 Maxime Graulich. All rights reserved.
-//
-
 #import <Foundation/Foundation.h>
 #import <Gmsh/onelab.h>
 
@@ -13,34 +5,32 @@
 
 @interface Parameter : NSObject
 {
-    @protected
-    NSString *name;
-    UILabel *label;
+@protected
+  NSString *name;
+  UILabel *label;
 }
 -(id)init;
 -(void)setFrame:(CGRect)frame;
 -(void)setLabelFrame:(CGRect)frame;
 -(NSString *)getName;
 -(UILabel *)getLabel;
--(bool)isReadOnly;
 +(double)getHeight;
 -(void)refresh;
 @end
 
 @interface ParameterStringList : Parameter <UIActionSheetDelegate>
 {
-    @protected
-    UIButton *button;
+@protected
+  UIButton *button;
 }
 -(id)initWithString:(onelab::string)string;
 -(UIPickerView *)getUIView;
 @end
 
-
 @interface ParameterNumberList : Parameter <UIActionSheetDelegate>
 {
-    @protected
-	UIButton *button;
+@protected
+  UIButton *button;
 }
 -(id)initWithNumber:(onelab::number)number;
 -(UITextField *)getUIView;
@@ -48,17 +38,26 @@
 
 @interface ParameterNumberCheckbox : Parameter
 {
-    @protected
-    UISwitch *checkbox;
+@protected
+  UISwitch *checkbox;
 }
 -(id)initWithNumber:(onelab::number)number;
 -(UISwitch *)getCheckbox;
 @end
 
+@interface ParameterNumberStepper : Parameter
+{
+@protected
+  UIStepper *stepper;
+}
+-(id)initWithNumber:(onelab::number)number;
+-(UIStepper *)getStepper;
+@end
+
 @interface ParameterNumberRange : Parameter
 {
-    @protected
-    UISlider *slider;
+@protected
+  UISlider *slider;
 }
 -(id)initWithNumber:(onelab::number)number;
 -(UISlider *)getSlider;
@@ -67,7 +66,7 @@
 @interface ParameterNumberTextbox : Parameter <UITextFieldDelegate>
 {
 @protected
-    UITextField *textbox;
+  UITextField *textbox;
 }
 -(id)initWithNumber:(onelab::number)number;
 -(UITextField *)getTextbox;
